@@ -6,22 +6,41 @@
 # @Author   : xxx
 import os
 
-from mgetool.imports import BatchFile
+from mgetool.imports import BatchFileMatch
 
 
 def run(args, parser):
-    # args = args.parse_args()
-    bf = BatchFile(args.path, suffix=args.suffix)
-    bf.filter_dir_name(include=args.dir_include, exclude=args.dir_exclude, layer=args.layer)
-    bf.filter_file_name(include=args.file_include, exclude=args.file_exclude)
-    bf.merge()
 
-    fdir = bf.file_dir
-    fdir.sort()
+    bf = BatchFileMatch(args.path, suffix=args.suffix)
+
+    if args.match_patten is not None:
+        bf.match(args.match_patten)
+
+    if " " in args.layer:
+        layer = str(args.layer).split(" ")
+        layer = [int(i) for i in layer]
+        if len(layer)==1:
+            layer = layer[0]
+    else:
+        layer = int(args.layer)
+
+    if args.dir_include is not None and " " in args.dir_include:
+        dir_include = str(args.dir_include).split(" ")
+    else:
+        dir_include = args.dir_include
+
+    if args.dir_exclude is not None and " " in args.dir_exclude:
+        dir_exclude = str(args.dir_exclude).split(" ")
+    else:
+        dir_exclude = args.dir_exclude
+
+    bf.filter_dir_name(include=dir_include, exclude=dir_exclude, layer=layer)
+    bf.filter_file_name(include=args.file_include, exclude=args.file_exclude)
+    bf.merge(abspath=args.abspath)
+
+    fdir = bf.get_leaf_dir()
     os.chdir(args.path)
-    if not args.abspath:
-        absp = os.path.abspath(args.path)
-        fdir = [i.replace(absp, ".") for i in fdir]
+
     with open(str(args.store_name), mode="w") as f:
         fdir = "\n".join(fdir)
         f.writelines(fdir)
@@ -40,6 +59,10 @@ class CLICommand:
 
         $ mgetool findpath -p /home/dir_name -if POSCAR
 
+        $ mgetool findpath  -id my_dir1 -ed my_dir2
+
+        mgetool findpath -id 'ini_opt' -ed 'Na' -l '-3 -2 -1'
+
     如果复制该脚本到某处，仅运行单个脚本:
 
     Example:
@@ -49,13 +72,14 @@ class CLICommand:
 
     @staticmethod
     def add_arguments(parser):
+        parser.add_argument('-m', '--match_patten', help='match_patten', type=str, default=None)
         parser.add_argument('-p', '--path', help='source path', type=str, default=".")
         parser.add_argument('-s', '--suffix', help='suffix of file', type=str, default=None)
         parser.add_argument('-if', '--file_include', help='include file name.', type=str, default=None)
         parser.add_argument('-ef', '--file_exclude', help='exclude file name.', type=str, default=None)
         parser.add_argument('-id', '--dir_include', help='include dir name.', type=str, default=None)
         parser.add_argument('-ed', '--dir_exclude', help='exclude dir name.', type=str, default=None)
-        parser.add_argument('-l', '--layer', help='dir depth, default the last layer', type=int, default=-1)
+        parser.add_argument('-l', '--layer', help='dir depth,default the last layer', type=str, default="-1")
         parser.add_argument('-abspath', '--abspath', help='return abspath', type=bool, default=False)
         parser.add_argument('-o', '--store_name', help='out file name, default paths.temp', type=str,
                             default="paths.temp")
@@ -73,13 +97,14 @@ if __name__ == '__main__':
                                                  "python findpath.py -p /home/dir_name -if POSCAR"
                                      )
 
-    parser.add_argument('-p', '--path', help='source path', type=str, default=".")
+    parser.add_argument('-m', '--match_patten', help='match_patten', type=str, default=None)
+    parser.add_argument('-p', '--path', help='source path', type=str, default="..")
     parser.add_argument('-s', '--suffix', help='suffix of file', type=str, default=None)
     parser.add_argument('-if', '--file_include', help='include file name.', type=str, default=None)
     parser.add_argument('-ef', '--file_exclude', help='exclude file name.', type=str, default=None)
     parser.add_argument('-id', '--dir_include', help='include dir name.', type=str, default=None)
     parser.add_argument('-ed', '--dir_exclude', help='exclude dir name.', type=str, default=None)
-    parser.add_argument('-l', '--layer', help='dir depth,default the last layer', type=int, default=-1)
+    parser.add_argument('-l', '--layer', help='dir depth,default the last layer', type=str, default="-1")
     parser.add_argument('-abspath', '--abspath', help='return abspath', type=bool, default=False)
     parser.add_argument('-o', '--store_name', help='out file name,default paths.temp', type=str, default="paths.temp")
     args = parser.parse_args()
